@@ -1,6 +1,6 @@
 """ Main entry point for the command line executable `wheatley`. """
 
 if __name__ == "__main__":
-    from main import main
+    from wheatley.main import main
 
     main()
